@@ -64,8 +64,10 @@ CK_CPPSTART
 
 #if GCC_VERSION_AT_LEAST(2,95,3)
 #define CK_ATTRIBUTE_UNUSED __attribute__ ((unused))
+#define CK_ATTRIBUTE_FORMAT(a, b, c) __attribute__ ((format (a, b, c)))
 #else
 #define CK_ATTRIBUTE_UNUSED
+#define CK_ATTRIBUTE_FORMAT(a, b, c)
 #endif /* GCC 2.95 */
 
 #if GCC_VERSION_AT_LEAST(2,5,0)
@@ -74,6 +76,20 @@ CK_CPPSTART
 #define CK_ATTRIBUTE_NORETURN
 #endif /* GCC 2.5 */
 
+#if GCC_VERSION_AT_LEAST(4,7,4) && (__STDC_VERSION__ >= 199901L)
+/* Operator _Pragma introduced in C99 */
+#define CK_DIAGNOSTIC_STRINGIFY(x) #x
+#define CK_DIAGNOSTIC_HELPER1(y) CK_DIAGNOSTIC_STRINGIFY(GCC diagnostic ignored y)
+#define CK_DIAGNOSTIC_HELPER2(z) CK_DIAGNOSTIC_HELPER1(#z)
+#define CK_DIAGNOSTIC_PUSH_IGNORE(w) \
+    _Pragma("GCC diagnostic push") \
+    _Pragma(CK_DIAGNOSTIC_HELPER2(w))
+#define CK_DIAGNOSTIC_POP(w) _Pragma ("GCC diagnostic pop")
+#else
+#define CK_DIAGNOSTIC_PUSH_IGNORE(w)
+#define CK_DIAGNOSTIC_POP(w)
+#endif /* GCC 4.7.4 */
+
 #undef GCC_VERSION_AT_LEAST
 
 #include <sys/types.h>
@@ -110,7 +126,7 @@ CK_CPPSTART
 /* check version numbers */
 
 #define CHECK_MAJOR_VERSION (0)
-#define CHECK_MINOR_VERSION (13)
+#define CHECK_MINOR_VERSION (15)
 #define CHECK_MICRO_VERSION (0)
 
 CK_DLL_EXP extern int CK_EXPORT check_major_version;
@@ -485,10 +501,10 @@ static void __testname ## _fn (int _i CK_ATTRIBUTE_UNUSED)
 #if 1
 CK_DLL_EXP void CK_EXPORT _ck_assert_failed(const char *file, int line,
                                             const char *expr,
-                                            ...) CK_ATTRIBUTE_NORETURN;
+                                            ...) CK_ATTRIBUTE_NORETURN CK_ATTRIBUTE_FORMAT(gnu_printf, 3, 4);
 #else
 CK_DLL_EXP void CK_EXPORT _ck_assert_failed(const char *file, int line,
-                                            const char *expr, ...);
+                                            const char *expr, ...) CK_ATTRIBUTE_FORMAT(gnu_printf, 3, 4);
 #endif
 
 /**
